Home | IUPHAR/BPS Guide to PHARMACOLOGY
Description: The IUPHAR/BPS Guide to PHARMACOLOGY. An expert-driven guide to pharmacological targets with quantitative information on the prescription medicines and experimental dugs that act on them. Developed as a joint initiative of the International Union of Basic and Clinical Pharmacology (IUPHAR) and the British Pharmacological Society (BPS) and is now the new home of the IUPHAR Database (IUPHAR-DB).

#### Quick links

### Targets

- G protein-coupled receptors
- Ion channels
- Nuclear hormone receptors
- Kinases
- Catalytic receptors
- Transporters
- Enzymes
- Other protein targets

### Ligands

- Approved drugs
- Synthetic organics
- Metabolites
- Natural products
- Endogenous peptides
- Other peptides
- Inorganics
- Antibodies
- Labelled ligands

### Resources

- Help documentation
- FAQ
- Tutorial
- Download data & reports
- REST web services

#### Recent Twitter activity

Sorry, this content is unavailable until you click to accept cookies from this site.
ACCEPT COOKIES
Tweets by GuidetoPHARM

Advanced Search: Targets | Target Pharmacology | Ligands | Chemical Structure

Current Release Version 2023.2 (7th August 2023). Read our release notes blog.

Coronavirus (Covid-19) - view our information page

#### Ligand Activity Charts

Use our interactive ligand activity charts to compare pharmacology across targets and species.

#### BJP Malaria Review

Just published in BJP the latest: IUPHAR Review 38:
Advances in malaria pharmacology and the online guide to MALARIA PHARMACOLOGY.

#### Immunopharmacology

IUPHAR Guide to IMMUNOPHARMACOLOGY
An immunological access-point to GtoPdb data

#### Malaria Pharmacology

IUPHAR/MMV Guide to MALARIA PHARMACOLOGY
Optimised access for the malaria research community

#### Latest News and Hot Topics in Pharmacology

powered by Surfing Waves

All news Our blog Hot topics Latest pairings

#### The Concise Guide to PHARMACOLOGY 2021/22

Access the table of contents

Please see the 5 minute introductory video on the Concise Guide:

Sorry, this content is unavailable until you click to accept cookies from this site.
ACCEPT COOKIES

#### Recent Publications

### Advances in malaria pharmacology and the online guide to MALARIA PHARMACOLOGY: IUPHAR review 38

Armstrong JF, Campo B, Alexander SPH, Arendse LB, Cheng X, Davenport AP, Faccenda E, Fidock DA, Godinez-Macias KP, Harding SD, Kato N, Lee MCS, Luth MR, Mazitschek R, Mittal N, Niles JC, Okombo J, Ottilie S, Pasaje CFA, Probst AS, Rawat M, Rocamora F, Sakata-Kato T, Southan C, Spedding M, Tye MA, Yang T, Zhao N, Davies JA. (2023) Br J Pharmacol. Online ahead of print. doi: 10.1111/bph.16144.

### Chronic liver diseases: From development to novel pharmacological therapies: IUPHAR Review 37

Borrello MT, Mann D. (2022) Br J Pharmacol. Online ahead of print. doi: 10.1111/bph.15853.

### IUPHAR Review CXIII: Nuclear Receptor Superfamily - Update 2023

Burris TP, de Vera IMS, Cote I, Flaveny CA, Wanninayake US, Chatterjee A, Walker JK, Steinauer N, Zhang J, Coons LA, Korach KS, Cain DW, Hollenberg AN, Webb P, Forrest D, Jetten AM, Edwards DP, Grimm SL, Hartig S, Lange CA, Richer JK, Sartorius CA, Tetel M, Billon C, Elgendy B, Hegazy L, Griffett K, Peinetti N, Burnstein KL, Hughes TS, Sitaula S, Stayrook KR, Culver A, Murray MH, Finck BN, Cidlowski J (2023) Pharmacol Rev. PHARMREV-INR-2021-000436. doi: 10.1124/pharmrev.121.000436. Online ahead of print.

### International Union of Basic and Clinical Pharmacology. CXII: Adenosine Receptors: A Further Update.

IJzerman AP, Jacobson KA, Müller CE, Cronstein BN, Cunha RA (2022) Pharmacol Rev. 74: 340-372.

Publication list

#### Celebrating >20 years of Servier support

Servier, a mid-size French Pharmaceutical company, has a long history in pharmacology, and has supported NC-IUPHAR for >20 years with unrestricted educational grants which have permitted the Paris meetings and thus progress of the database.